@@ -2,10 +2,7 @@
 module YesodCoreTest.InternalRequest (internalRequestTest) where
 
 import Data.List (nub)
-import System.Random (StdGen, mkStdGen)
-
 import Network.Wai as W
-import Network.Wai.Test
 import Yesod.Core.Internal (randomString, parseWaiRequest)
 import Test.Hspec
 import Data.Monoid (mempty)
